@@ -1,5 +1,5 @@
 package IO::Pager;
-our $VERSION = "0.43"; #Untouched since 0.43
+our $VERSION = "1.00"; #Untouched since 1.00
 
 use 5.008; #At least, for decent perlio, and other modernisms
 use strict;
@@ -12,14 +12,14 @@ use Symbol;
 use overload '+' => "PID", bool=> "PID";
 
 our $SIGPIPE;
-our $oldPAGER = $PAGER;
+my $oldPAGER = $PAGER;
 
 sub find_pager {
   # Return the name (or path) of a pager that IO::Pager can use
   my $io_pager;
 
   #Permit explicit use of pure perl pager
-  local $_ = 'Term::Pager';
+  local $_ = 'IO::Pager::less';
   return $_ if $_[0] eq $_ or $PAGER eq $_;
 
   # Use File::Which if available (strongly recommended)
@@ -46,7 +46,7 @@ sub find_pager {
     $io_pager = _check_pagers(\@pagers, $which );
   }
 
-  # If all else fails, default to more (actually Term::Pager first)
+  # If all else fails, default to more (actually IO::Pager::less first)
   $io_pager ||= 'more';
 
   return $io_pager;
@@ -78,15 +78,12 @@ sub _check_pagers {
 #Should have this as first block for clarity, but not with its use of a sub :-/
 BEGIN { # Set the $ENV{PAGER} to something reasonable
   $PAGER = find_pager();
-
-  #We have a hack to get modern Term::Pager for now
-  ##Do we have modern Term::Pager? If so, use it instead of hopeful more
-  if( ($PAGER =~ 'more' and $oldPAGER ne 'more') or $PAGER eq 'Term::Pager' ){
-      my $io_pager = $PAGER;
-      eval "use IO::Pager::Perl";
-      $PAGER = $io_pager if $@ or not defined $PAGER;
-  #    eval "use Term::Pager 1.5";
-  #    $PAGER = 'Term::Pager' unless $@;
+  
+  if( ($PAGER =~ 'more' and $oldPAGER ne 'more') or
+       $PAGER eq 'IO::Pager::less' ){
+    my $io_pager = $PAGER;
+    eval "use IO::Pager::less";
+    $PAGER = $io_pager if $@ or not defined $PAGER;
   }
 }
 
@@ -516,7 +513,7 @@ executable.
 
 =item /usr/bin/less
 
-=item tp via L<IO::Pager::Perl>
+=item L<IO::Pager::Perl> as C<tp> via L<IO::Pager::less>
 
 =item /usr/bin/more
 
